@@ -12,25 +12,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import urls
+from django.urls import re_path
 
 from manila_ui.dashboards.project.share_networks import views
 
 
 urlpatterns = [
-    urls.url(
+    re_path(
         r'^$',
         views.ShareNetworksView.as_view(),
         name='index'),
-    urls.url(
+    re_path(
         r'^create_share_network$',
         views.Create.as_view(),
         name='share_network_create'),
-    urls.url(
+    re_path(
         r'^(?P<share_network_id>[^/]+)/update$',
         views.Update.as_view(),
         name='share_network_update'),
-    urls.url(
+    re_path(
         r'^(?P<share_network_id>[^/]+)$',
         views.Detail.as_view(),
         name='share_network_detail'),
