@@ -13,9 +13,8 @@
 #    under the License.
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions
-from horizon import forms
 from horizon import tables
 from horizon import tabs
 from horizon.utils import memoized
@@ -24,7 +23,6 @@ from openstack_dashboard.api import base
 from openstack_dashboard.api import neutron
 
 from manila_ui.api import manila
-from manila_ui.dashboards.project.share_networks import forms as sn_forms
 from manila_ui.dashboards.project.share_networks import tables as sn_tables
 from manila_ui.dashboards.project.share_networks import tabs as sn_tabs
 import manila_ui.dashboards.project.share_networks.workflows as sn_workflows
@@ -43,16 +41,6 @@ class ShareNetworksView(tables.MultiTableView):
         try:
             share_networks = manila.share_network_list(
                 self.request, detailed=True)
-            if base.is_service_enabled(self.request, 'network'):
-                neutron_net_names = dict((net.id, net.name) for net in
-                                         neutron.network_list(self.request))
-                neutron_subnet_names = dict((net.id, net.name) for net in
-                                            neutron.subnet_list(self.request))
-                for sn in share_networks:
-                    sn.neutron_net = neutron_net_names.get(
-                        sn.neutron_net_id) or sn.neutron_net_id or "-"
-                    sn.neutron_subnet = neutron_subnet_names.get(
-                        sn.neutron_subnet_id) or sn.neutron_subnet_id or "-"
         except Exception:
             share_networks = []
             exceptions.handle(
@@ -75,13 +63,9 @@ class Update(workflows.WorkflowView):
         return context
 
 
-class Create(forms.ModalFormView):
-    form_class = sn_forms.Create
+class Create(workflows.WorkflowView):
+    workflow_class = sn_workflows.CreateShareNetworkWorkflow
     form_id = "create_share_network"
-    template_name = 'project/share_networks/create.html'
-    modal_header = _("Create Share Network")
-    modal_id = "create_share_network_modal"
-    submit_label = _("Create")
     submit_url = reverse_lazy(
         "horizon:project:share_networks:share_network_create")
     success_url = reverse_lazy("horizon:project:share_networks:index")
@@ -110,19 +94,32 @@ class Detail(tabs.TabView):
             share_net_id = self.kwargs['share_network_id']
             share_net = manila.share_network_get(self.request, share_net_id)
             if base.is_service_enabled(self.request, 'network'):
-                try:
-                    share_net.neutron_net = neutron.network_get(
-                        self.request, share_net.neutron_net_id).name_or_id
-                except (
-                    neutron.neutron_client.exceptions.NeutronClientException):
-                    share_net.neutron_net = _("Unknown")
-                try:
-                    share_net.neutron_subnet = neutron.subnet_get(
-                        self.request, share_net.neutron_subnet_id).name_or_id
-                except (
-                    neutron.neutron_client.exceptions.NeutronClientException):
-                    share_net.neutron_subnet = _("Unknown")
-
+                for subnet in share_net.share_network_subnets:
+                    # Neutron Net ID
+                    try:
+                        subnet["neutron_net"] = neutron.network_get(
+                            self.request, subnet["neutron_net_id"]).name_or_id
+                    except (
+                        neutron.neutron_client.exceptions
+                        .NeutronClientException
+                        ):
+                        subnet["neutron_net"] = _("Unknown")
+                    # Neutron Subnet ID
+                    try:
+                        subnet["neutron_subnet"] = neutron.subnet_get(
+                            self.request,
+                            subnet["neutron_subnet_id"]).name_or_id
+                    except (
+                        neutron.neutron_client.exceptions
+                        .NeutronClientException
+                        ):
+                        subnet["neutron_subnet"] = _("Unknown")
+            # List all azs if availability_zone is None
+            availability_zones = manila.availability_zone_list(self.request)
+            az_list = ", ".join([az.name for az in availability_zones])
+            for subnet in share_net.share_network_subnets:
+                if subnet["availability_zone"] is None:
+                    subnet["availability_zone"] = az_list
             share_net.sec_services = (
                 manila.share_network_security_service_list(
                     self.request, share_net_id))
