@@ -33,6 +33,7 @@ class ManilaApiTests(base.APITestCase):
 
     @ddt.data(
         {},
+        None,
         {"name": "fake_share"},
         {"limit": "3"},
         {"host": "fake_share_host"},
@@ -44,8 +45,9 @@ class ManilaApiTests(base.APITestCase):
         self.assertEqual(
             self.manilaclient.shares.list.return_value, result)
 
+        expected_kwargs = kwargs or {}
         self.manilaclient.shares.list.assert_called_once_with(
-            search_opts=kwargs)
+            search_opts=expected_kwargs)
 
     def test_share_get(self):
         api.share_get(self.request, self.id)
@@ -235,10 +237,25 @@ class ManilaApiTests(base.APITestCase):
 
     def test_migration_cancel(self):
         api.migration_cancel(self.request, 'fake_share')
-
         self.manilaclient.shares.migration_cancel.assert_called_once_with(
             'fake_share')
 
+    @ddt.data(
+        ('name_updated_1', 'description_updated', True),
+        ('name_updated_2', 'description_updated', False),
+        ('name_updated_3', None, True),
+    )
+    @ddt.unpack
+    def test_share_type_update(
+            self, name, description, is_public):
+        api.share_type_update(self.request, self.id, name,
+                              description, is_public)
+
+        self.manilaclient.share_types.get.return_value.update.\
+            assert_called_once_with(name=name,
+                                    description=description,
+                                    is_public=is_public)
+
     def test_migration_get_progress(self):
         api.migration_get_progress(self.request, 'fake_share')
 
@@ -395,6 +412,7 @@ class ManilaApiTests(base.APITestCase):
             "description": None,
             "neutron_net_id": None,
             "neutron_subnet_id": None,
+            "availability_zone": None
         }
         expected_kwargs.update(**kwargs)
 
@@ -809,18 +827,16 @@ class ManilaApiTests(base.APITestCase):
 
         self.manilaclient.share_replicas.list.assert_called_once_with("FOO")
 
-    @ddt.data(None, "foo_share_network")
-    def test_share_replica_create(self, share_network):
+    def test_share_replica_create(self):
         share = "FOO_share"
         availability_zone = "BAR_availability_zone"
 
         api.share_replica_create(
-            self.request, share, availability_zone, share_network)
+            self.request, share, availability_zone)
 
         self.manilaclient.share_replicas.create.assert_called_once_with(
             share,
-            availability_zone=availability_zone,
-            share_network=share_network,
+            availability_zone=availability_zone
         )
 
     def test_share_replica_get(self):
