@@ -18,6 +18,7 @@ from horizon import exceptions as horizon_exceptions
 from neutronclient.client import exceptions
 from openstack_dashboard.api import keystone as api_keystone
 from openstack_dashboard.api import neutron as api_neutron
+from oslo_utils import timeutils
 from unittest import mock
 
 from manila_ui.api import manila as api_manila
@@ -39,8 +40,15 @@ class ShareNetworksTests(test.BaseAdminViewTests):
         # Reset taken list of projects to avoid test interference
         utils.PROJECTS = {}
 
+    class FakeAZ(object):
+        def __init__(self, name, id):
+            self.name = name
+            self.id = id
+            self.created_at = timeutils.utcnow()
+
     def test_detail_view(self):
         share_net = test_data.active_share_network
+        share_network_subnets = share_net.share_network_subnets
         sec_service = test_data.sec_service
         self.mock_object(
             api_manila, "share_server_list", mock.Mock(return_value=[]))
@@ -55,6 +63,10 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             api_neutron, "network_get", mock.Mock(return_value=network))
         self.mock_object(
             api_neutron, "subnet_get", mock.Mock(return_value=subnet))
+        self.mock_object(
+            api_manila, "availability_zone_list",
+            mock.Mock(return_value=[self.FakeAZ('fake_az', 'fake_az')])
+        )
         url = reverse('horizon:admin:share_networks:share_network_detail',
                       args=[share_net.id])
 
@@ -65,11 +77,23 @@ class ShareNetworksTests(test.BaseAdminViewTests):
                             1, 200)
         self.assertContains(res, "<dd>%s</dd>" % share_net.name, 1, 200)
         self.assertContains(res, "<dd>%s</dd>" % share_net.id, 1, 200)
-        self.assertContains(res, "<dd>%s</dd>" % network.name_or_id, 1, 200)
-        self.assertContains(res, "<dd>%s</dd>" % subnet.name_or_id, 1, 200)
+        for sub in share_network_subnets:
+            self.assertContains(res, "<a href=\"/admin/networks"
+                                "/%s/detail\">%s</a>" % (
+                                    sub['neutron_net_id'],
+                                    network.name), 1, 200)
         self.assertContains(res, "<a href=\"/admin/security_services"
                                  "/%s\">%s</a>" % (sec_service.id,
                                                    sec_service.name), 1, 200)
+        network_get_calls = [mock.call(mock.ANY, sub['neutron_net_id']
+                                       ) for sub in share_network_subnets]
+        subnet_get_calls = [mock.call(mock.ANY, sub['neutron_subnet_id']
+                                      ) for sub in share_network_subnets]
+
+        api_neutron.network_get.assert_has_calls(network_get_calls,
+                                                 any_order=True)
+        api_neutron.subnet_get.assert_has_calls(subnet_get_calls,
+                                                any_order=True)
         self.assertNoMessages()
         api_manila.share_network_security_service_list.assert_called_once_with(
             mock.ANY, share_net.id)
@@ -77,14 +101,11 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             mock.ANY, search_opts={'share_network_id': share_net.id})
         api_manila.share_network_get.assert_called_once_with(
             mock.ANY, share_net.id)
-        api_neutron.network_get.assert_called_once_with(
-            mock.ANY, share_net.neutron_net_id)
-        api_neutron.subnet_get.assert_called_once_with(
-            mock.ANY, share_net.neutron_subnet_id)
 
     def test_detail_view_network_not_found(self):
         share_net = test_data.active_share_network
         sec_service = test_data.sec_service
+        share_network_subnets = share_net.share_network_subnets
         url = reverse('horizon:admin:share_networks:share_network_detail',
                       args=[share_net.id])
         self.mock_object(
@@ -100,7 +121,10 @@ class ShareNetworksTests(test.BaseAdminViewTests):
         self.mock_object(
             api_neutron, "subnet_get", mock.Mock(
                 side_effect=exceptions.NeutronClientException('fake', 500)))
-
+        self.mock_object(
+            api_manila, "availability_zone_list",
+            mock.Mock(return_value=[])
+        )
         res = self.client.get(url)
 
         self.assertContains(res, "<h1>Share Network Details: %s</h1>"
@@ -108,10 +132,19 @@ class ShareNetworksTests(test.BaseAdminViewTests):
                             1, 200)
         self.assertContains(res, "<dd>%s</dd>" % share_net.name, 1, 200)
         self.assertContains(res, "<dd>%s</dd>" % share_net.id, 1, 200)
-        self.assertContains(res, "<dd>Unknown</dd>", 2, 200)
-        self.assertNotContains(res, "<dd>%s</dd>" % share_net.neutron_net_id)
-        self.assertNotContains(res,
-                               "<dd>%s</dd>" % share_net.neutron_subnet_id)
+        for sub in share_network_subnets:
+            self.assertNotContains(res, "<dd>%s</dd>" % sub['neutron_net_id'])
+            self.assertNotContains(res,
+                                   "<dd>%s</dd>" % sub['neutron_subnet_id'])
+        network_get_calls = [mock.call(mock.ANY, sub['neutron_net_id']
+                                       ) for sub in share_network_subnets]
+        subnet_get_calls = [mock.call(mock.ANY, sub['neutron_subnet_id']
+                                      ) for sub in share_network_subnets]
+
+        api_neutron.network_get.assert_has_calls(network_get_calls,
+                                                 any_order=True)
+        api_neutron.subnet_get.assert_has_calls(subnet_get_calls,
+                                                any_order=True)
         self.assertContains(res, "<a href=\"/admin/security_services"
                                  "/%s\">%s</a>" % (sec_service.id,
                                                    sec_service.name), 1, 200)
@@ -122,10 +155,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
             mock.ANY, search_opts={'share_network_id': share_net.id})
         api_manila.share_network_get.assert_called_once_with(
             mock.ANY, share_net.id)
-        api_neutron.network_get.assert_called_once_with(
-            mock.ANY, share_net.neutron_net_id)
-        api_neutron.subnet_get.assert_called_once_with(
-            mock.ANY, share_net.neutron_subnet_id)
 
     def test_detail_view_with_exception(self):
         url = reverse('horizon:admin:share_networks:share_network_detail',
@@ -143,10 +172,6 @@ class ShareNetworksTests(test.BaseAdminViewTests):
     def test_delete_share_network(self):
         share_network = test_data.inactive_share_network
         formData = {'action': 'share_networks__delete__%s' % share_network.id}
-        self.mock_object(
-            api_neutron, "network_list", mock.Mock(return_value=[]))
-        self.mock_object(
-            api_neutron, "subnet_list", mock.Mock(return_value=[]))
         self.mock_object(api_manila, "share_network_delete")
         self.mock_object(
             api_manila, "share_network_list",
@@ -156,11 +181,9 @@ class ShareNetworksTests(test.BaseAdminViewTests):
 
         res = self.client.post(INDEX_URL, formData)
 
+        self.assertRedirectsNoFollow(res, INDEX_URL)
         api_keystone.tenant_list.assert_called_once_with(mock.ANY)
         api_manila.share_network_delete.assert_called_once_with(
-            mock.ANY, test_data.inactive_share_network.id)
+            mock.ANY, share_network.id)
         api_manila.share_network_list.assert_called_once_with(
             mock.ANY, detailed=True, search_opts={'all_tenants': True})
-        api_neutron.network_list.assert_called_once_with(mock.ANY)
-        api_neutron.subnet_list.assert_called_once_with(mock.ANY)
-        self.assertRedirectsNoFollow(res, INDEX_URL)
